==> jc-1.4.0.tar.gz: javax/swing/JPopupMenu__24HeavyWeightPopup.h <==
// class javax.swing.JPopupMenu$HeavyWeightPopup

// class file dependencies
// @dep_class d547e55bb64f2ca8 java_awt_Component
// @dep_class a9ec1dfd683af396 java_awt_Container
// @dep_class 184d12f43c3697c9 java_awt_Window
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class b101c157cbce7d1d javax_swing_JPopupMenu__24HeavyWeightPopup
// @dep_class d5aa9936e1d1fbbe javax_swing_JWindow

// header file dependencies
// @dep_header javax_swing_JWindow

#include "javax/swing/JWindow.h"

#ifndef _JC_javax_swing_JPopupMenu__24HeavyWeightPopup_H_
#define _JC_javax_swing_JPopupMenu__24HeavyWeightPopup_H_

// Forward structure declarations
struct _jc_java_awt_Container$object;
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_JPopupMenu$object;

// Typedefs
typedef struct _jc_javax_swing_JPopupMenu__24HeavyWeightPopup$sub_refs	_jc_javax_swing_JPopupMenu__24HeavyWeightPopup$sub_refs;
typedef struct _jc_javax_swing_JPopupMenu__24HeavyWeightPopup$sub_nonrefs	_jc_javax_swing_JPopupMenu__24HeavyWeightPopup$sub_nonrefs;
typedef struct _jc_javax_swing_JPopupMenu__24HeavyWeightPopup$refs	_jc_javax_swing_JPopupMenu__24HeavyWeightPopup$refs;
typedef struct _jc_javax_swing_JPopupMenu__24HeavyWeightPopup$nonrefs	_jc_javax_swing_JPopupMenu__24HeavyWeightPopup$nonrefs;
typedef struct _jc_javax_swing_JPopupMenu__24HeavyWeightPopup$object	_jc_javax_swing_JPopupMenu__24HeavyWeightPopup$object;

typedef const struct _jc_javax_swing_JPopupMenu__24HeavyWeightPopup$vmethods	_jc_javax_swing_JPopupMenu__24HeavyWeightPopup$vmethods;
typedef const struct _jc_javax_swing_JPopupMenu__24HeavyWeightPopup$vtable	_jc_javax_swing_JPopupMenu__24HeavyWeightPopup$vtable;
typedef const struct _jc_javax_swing_JPopupMenu__24HeavyWeightPopup$vtype	_jc_javax_swing_JPopupMenu__24HeavyWeightPopup$vtype;

// Constructors
extern void _jc_javax_swing_JPopupMenu__24HeavyWeightPopup$method$_init$0ad2bcb8655c238d(_jc_env *, struct _jc_javax_swing_JPopupMenu__24HeavyWeightPopup$object *, struct _jc_javax_swing_JPopupMenu$object *, struct _jc_java_awt_Container$object *);

// Virtual methods
extern void _jc_javax_swing_JPopupMenu__24HeavyWeightPopup$method$show$9d69c93242b99fe6(_jc_env *, struct _jc_javax_swing_JPopupMenu__24HeavyWeightPopup$object *, jint, jint, jint, jint);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_JPopupMenu__24HeavyWeightPopup$method_info$show$9d69c93242b99fe6;

// Virtual methods structure
struct _jc_javax_swing_JPopupMenu__24HeavyWeightPopup$vmethods {
	void	(*show$9d69c93242b99fe6)(_jc_env *, struct _jc_javax_swing_JPopupMenu__24HeavyWeightPopup$object *, jint, jint, jint, jint);
};

// Vtable
struct _jc_javax_swing_JPopupMenu__24HeavyWeightPopup$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_Component$vmethods	java_awt_Component;
	_jc_java_awt_Container$vmethods	java_awt_Container;
	_jc_java_awt_Window$vmethods	java_awt_Window;
	_jc_javax_swing_JWindow$vmethods	javax_swing_JWindow;
	_jc_javax_swing_JPopupMenu__24HeavyWeightPopup$vmethods	javax_swing_JPopupMenu__24HeavyWeightPopup;
};

// Vtype
struct _jc_javax_swing_JPopupMenu__24HeavyWeightPopup$vtype {
	_jc_type			type;
	_jc_javax_swing_JPopupMenu__24HeavyWeightPopup$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_JPopupMenu__24HeavyWeightPopup$sub_refs {
	struct _jc_javax_swing_JPopupMenu$object	*this;
};

// Reference instance fields (object)
struct _jc_javax_swing_JPopupMenu__24HeavyWeightPopup$refs {
    _jc_javax_swing_JPopupMenu__24HeavyWeightPopup$sub_refs	javax_swing_JPopupMenu__24HeavyWeightPopup;
    _jc_javax_swing_JWindow$sub_refs	javax_swing_JWindow;
    _jc_java_awt_Window$sub_refs	java_awt_Window;
    _jc_java_awt_Container$sub_refs	java_awt_Container;
    _jc_java_awt_Component$sub_refs	java_awt_Component;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_JPopupMenu__24HeavyWeightPopup$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_JPopupMenu__24HeavyWeightPopup$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_Component$sub_nonrefs	java_awt_Component;
    _jc_java_awt_Container$sub_nonrefs	java_awt_Container;
    _jc_java_awt_Window$sub_nonrefs	java_awt_Window;
    _jc_javax_swing_JWindow$sub_nonrefs	javax_swing_JWindow;
    _jc_javax_swing_JPopupMenu__24HeavyWeightPopup$sub_nonrefs	javax_swing_JPopupMenu__24HeavyWeightPopup;
};

// Object instance structure
struct _jc_javax_swing_JPopupMenu__24HeavyWeightPopup$object {
	_jc_javax_swing_JPopupMenu__24HeavyWeightPopup$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_JPopupMenu__24HeavyWeightPopup$vtype	*vtype;
	_jc_javax_swing_JPopupMenu__24HeavyWeightPopup$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_JPopupMenu__24HeavyWeightPopup$vtype _jc_javax_swing_JPopupMenu__24HeavyWeightPopup$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_JPopupMenu__24HeavyWeightPopup, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_JPopupMenu__24HeavyWeightPopup$class_object;

#endif	/* _JC_javax_swing_JPopupMenu__24HeavyWeightPopup_H_ */

==> jc-1.4.5.tar.gz: javax/swing/JPopupMenu__24HeavyWeightPopup.h <==
// class javax.swing.JPopupMenu$HeavyWeightPopup

// class file dependencies
// @dep_class 5a2bf6e9db456f42 java_awt_Component
// @dep_class a9ec1dfd683af396 java_awt_Container
// @dep_class fd4ae025aa56ceb9 java_awt_Window
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class b101c157cbce7d1d javax_swing_JPopupMenu__24HeavyWeightPopup
// @dep_class d5aa9936e1d1fbbe javax_swing_JWindow

// header file dependencies
// @dep_header javax_swing_JWindow

#include "javax/swing/JWindow.h"

#ifndef _JC_javax_swing_JPopupMenu__24HeavyWeightPopup_H_
#define _JC_javax_swing_JPopupMenu__24HeavyWeightPopup_H_

// Forward structure declarations
struct _jc_java_awt_Container$object;
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_JPopupMenu$object;

// Typedefs
typedef struct _jc_javax_swing_JPopupMenu__24HeavyWeightPopup$sub_refs	_jc_javax_swing_JPopupMenu__24HeavyWeightPopup$sub_refs;
typedef struct _jc_javax_swing_JPopupMenu__24HeavyWeightPopup$sub_nonrefs	_jc_javax_swing_JPopupMenu__24HeavyWeightPopup$sub_nonrefs;
typedef struct _jc_javax_swing_JPopupMenu__24HeavyWeightPopup$refs	_jc_javax_swing_JPopupMenu__24HeavyWeightPopup$refs;
typedef struct _jc_javax_swing_JPopupMenu__24HeavyWeightPopup$nonrefs	_jc_javax_swing_JPopupMenu__24HeavyWeightPopup$nonrefs;
typedef struct _jc_javax_swing_JPopupMenu__24HeavyWeightPopup$object	_jc_javax_swing_JPopupMenu__24HeavyWeightPopup$object;

typedef const struct _jc_javax_swing_JPopupMenu__24HeavyWeightPopup$vmethods	_jc_javax_swing_JPopupMenu__24HeavyWeightPopup$vmethods;
typedef const struct _jc_javax_swing_JPopupMenu__24HeavyWeightPopup$vtable	_jc_javax_swing_JPopupMenu__24HeavyWeightPopup$vtable;
typedef const struct _jc_javax_swing_JPopupMenu__24HeavyWeightPopup$vtype	_jc_javax_swing_JPopupMenu__24HeavyWeightPopup$vtype;

// Constructors
extern void _jc_javax_swing_JPopupMenu__24HeavyWeightPopup$method$_init$0ad2bcb8655c238d(_jc_env *, struct _jc_javax_swing_JPopupMenu__24HeavyWeightPopup$object *, struct _jc_javax_swing_JPopupMenu$object *, struct _jc_java_awt_Container$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_javax_swing_JPopupMenu__24HeavyWeightPopup$method$show$9d69c93242b99fe6(_jc_env *, struct _jc_javax_swing_JPopupMenu__24HeavyWeightPopup$object *, jint, jint, jint, jint) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_JPopupMenu__24HeavyWeightPopup$method_info$show$9d69c93242b99fe6;

// Virtual methods structure
struct _jc_javax_swing_JPopupMenu__24HeavyWeightPopup$vmethods {
	void	(*show$9d69c93242b99fe6)(_jc_env *, struct _jc_javax_swing_JPopupMenu__24HeavyWeightPopup$object *, jint, jint, jint, jint) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_JPopupMenu__24HeavyWeightPopup$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_Component$vmethods	java_awt_Component;
	_jc_java_awt_Container$vmethods	java_awt_Container;
	_jc_java_awt_Window$vmethods	java_awt_Window;
	_jc_javax_swing_JWindow$vmethods	javax_swing_JWindow;
	_jc_javax_swing_JPopupMenu__24HeavyWeightPopup$vmethods	javax_swing_JPopupMenu__24HeavyWeightPopup;
};

// Vtype
struct _jc_javax_swing_JPopupMenu__24HeavyWeightPopup$vtype {
	_jc_type			type;
	_jc_javax_swing_JPopupMenu__24HeavyWeightPopup$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_JPopupMenu__24HeavyWeightPopup$sub_refs {
	struct _jc_javax_swing_JPopupMenu$object	*this;
};

// Reference instance fields (object)
struct _jc_javax_swing_JPopupMenu__24HeavyWeightPopup$refs {
    _jc_javax_swing_JPopupMenu__24HeavyWeightPopup$sub_refs	javax_swing_JPopupMenu__24HeavyWeightPopup;
    _jc_javax_swing_JWindow$sub_refs	javax_swing_JWindow;
    _jc_java_awt_Window$sub_refs	java_awt_Window;
    _jc_java_awt_Container$sub_refs	java_awt_Container;
    _jc_java_awt_Component$sub_refs	java_awt_Component;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_JPopupMenu__24HeavyWeightPopup$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_JPopupMenu__24HeavyWeightPopup$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_Component$sub_nonrefs	java_awt_Component;
    _jc_java_awt_Container$sub_nonrefs	java_awt_Container;
    _jc_java_awt_Window$sub_nonrefs	java_awt_Window;
    _jc_javax_swing_JWindow$sub_nonrefs	javax_swing_JWindow;
    _jc_javax_swing_JPopupMenu__24HeavyWeightPopup$sub_nonrefs	javax_swing_JPopupMenu__24HeavyWeightPopup;
};

// Object instance structure
struct _jc_javax_swing_JPopupMenu__24HeavyWeightPopup$object {
	_jc_javax_swing_JPopupMenu__24HeavyWeightPopup$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_JPopupMenu__24HeavyWeightPopup$vtype	*vtype;
	_jc_javax_swing_JPopupMenu__24HeavyWeightPopup$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_JPopupMenu__24HeavyWeightPopup$vtype _jc_javax_swing_JPopupMenu__24HeavyWeightPopup$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_JPopupMenu__24HeavyWeightPopup, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_JPopupMenu__24HeavyWeightPopup$class_object;

#endif	/* _JC_javax_swing_JPopupMenu__24HeavyWeightPopup_H_ */
